package Monitoring::GLPlugin::SNMP::MibsAndOids::WEBGRAPH8XTHERMOMETERMIB;

$Monitoring::GLPlugin::SNMP::MibsAndOids::origin->{'WebGraph-8xThermometer-MIB'} = {
  url => '',
  name => 'WebGraph-8xThermometer-MIB',
};

$Monitoring::GLPlugin::SNMP::MibsAndOids::mib_ids->{'WebGraph-8xThermometer-MIB'} =
  '1.3.6.1.4.1.5040.1.2.6';

$Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'WebGraph-8xThermometer-MIB'} = {
  'wut' => '1.3.6.1.4.1.5040',
  'wtComServer' => '1.3.6.1.4.1.5040.1',
  'wtWebio' => '1.3.6.1.4.1.5040.1.2',
  'wtWebioAn8Graph' => '1.3.6.1.4.1.5040.1.2.6',
  'wtWebioAn8GraphTemp' => '1.3.6.1.4.1.5040.1.2.6.1',
  'wtWebioAn8GraphSensors' => '1.3.6.1.4.1.5040.1.2.6.1.1',
  'wtWebioAn8GraphSensorTable' => '1.3.6.1.4.1.5040.1.2.6.1.2',
  'wtWebioAn8GraphSensorEntry' => '1.3.6.1.4.1.5040.1.2.6.1.2.1',
  'wtWebioAn8GraphSensorNo' => '1.3.6.1.4.1.5040.1.2.6.1.2.1.1',
  'wtWebioAn8GraphTempValueTable' => '1.3.6.1.4.1.5040.1.2.6.1.3',
  'wtWebioAn8GraphTempValueEntry' => '1.3.6.1.4.1.5040.1.2.6.1.3.1',
  'wtWebioAn8GraphTempValue' => '1.3.6.1.4.1.5040.1.2.6.1.3.1.1',
  'wtWebioAn8GraphBinaryTempValueTable' => '1.3.6.1.4.1.5040.1.2.6.1.4',
  'wtWebioAn8GraphBinaryTempValueEntry' => '1.3.6.1.4.1.5040.1.2.6.1.4.1',
  'wtWebioAn8GraphBinaryTempValue' => '1.3.6.1.4.1.5040.1.2.6.1.4.1.1',
  'wtWebioAn8GraphTempValuePktTable' => '1.3.6.1.4.1.5040.1.2.6.1.8',
  'wtWebioAn8GraphTempValuePktEntry' => '1.3.6.1.4.1.5040.1.2.6.1.8.1',
  'wtWebioAn8GraphTempValuePkt' => '1.3.6.1.4.1.5040.1.2.6.1.8.1.1',
  'wtWebioAn8GraphSessCntrl' => '1.3.6.1.4.1.5040.1.2.6.2',
  'wtWebioAn8GraphSessCntrlPassword' => '1.3.6.1.4.1.5040.1.2.6.2.1',
  'wtWebioAn8GraphSessCntrlConfigMode' => '1.3.6.1.4.1.5040.1.2.6.2.2',
  'wtWebioAn8GraphSessCntrlConfigModeDefinition' => 'WebGraph-8xThermometer-MIB::wtWebioAn8GraphSessCntrlConfigMode',
  'wtWebioAn8GraphSessCntrlLogout' => '1.3.6.1.4.1.5040.1.2.6.2.3',
  'wtWebioAn8GraphSessCntrlAdminPassword' => '1.3.6.1.4.1.5040.1.2.6.2.4',
  'wtWebioAn8GraphSessCntrlConfigPassword' => '1.3.6.1.4.1.5040.1.2.6.2.5',
  'wtWebioAn8GraphConfig' => '1.3.6.1.4.1.5040.1.2.6.3',
  'wtWebioAn8GraphDevice' => '1.3.6.1.4.1.5040.1.2.6.3.1',
  'wtWebioAn8GraphText' => '1.3.6.1.4.1.5040.1.2.6.3.1.1',
  'wtWebioAn8GraphDeviceName' => '1.3.6.1.4.1.5040.1.2.6.3.1.1.1',
  'wtWebioAn8GraphDeviceText' => '1.3.6.1.4.1.5040.1.2.6.3.1.1.2',
  'wtWebioAn8GraphDeviceLocation' => '1.3.6.1.4.1.5040.1.2.6.3.1.1.3',
  'wtWebioAn8GraphDeviceContact' => '1.3.6.1.4.1.5040.1.2.6.3.1.1.4',
  'wtWebioAn8GraphTimeDate' => '1.3.6.1.4.1.5040.1.2.6.3.1.2',
  'wtWebioAn8GraphTimeZone' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1',
  'wtWebioAn8GraphTzOffsetHrs' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.1',
  'wtWebioAn8GraphTzOffsetMin' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.2',
  'wtWebioAn8GraphTzEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.3',
  'wtWebioAn8GraphStTzOffsetHrs' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.4',
  'wtWebioAn8GraphStTzOffsetMin' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.5',
  'wtWebioAn8GraphStTzEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.6',
  'wtWebioAn8GraphStTzStartMonth' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.7',
  'wtWebioAn8GraphStTzStartMonthDefinition' => 'WebGraph-8xThermometer-MIB::wtWebioAn8GraphStTzStartMonth',
  'wtWebioAn8GraphStTzStartMode' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.8',
  'wtWebioAn8GraphStTzStartModeDefinition' => 'WebGraph-8xThermometer-MIB::wtWebioAn8GraphStTzStartMode',
  'wtWebioAn8GraphStTzStartWday' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.9',
  'wtWebioAn8GraphStTzStartWdayDefinition' => 'WebGraph-8xThermometer-MIB::wtWebioAn8GraphStTzStartWday',
  'wtWebioAn8GraphStTzStartHrs' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.10',
  'wtWebioAn8GraphStTzStartMin' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.11',
  'wtWebioAn8GraphStTzStopMonth' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.12',
  'wtWebioAn8GraphStTzStopMonthDefinition' => 'WebGraph-8xThermometer-MIB::wtWebioAn8GraphStTzStopMonth',
  'wtWebioAn8GraphStTzStopMode' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.13',
  'wtWebioAn8GraphStTzStopModeDefinition' => 'WebGraph-8xThermometer-MIB::wtWebioAn8GraphStTzStopMode',
  'wtWebioAn8GraphStTzStopWday' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.14',
  'wtWebioAn8GraphStTzStopWdayDefinition' => 'WebGraph-8xThermometer-MIB::wtWebioAn8GraphStTzStopWday',
  'wtWebioAn8GraphStTzStopHrs' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.15',
  'wtWebioAn8GraphStTzStopMin' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.1.16',
  'wtWebioAn8GraphTimeServer' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.2',
  'wtWebioAn8GraphTimeServer1' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.2.1',
  'wtWebioAn8GraphTimeServer2' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.2.2',
  'wtWebioAn8GraphTsEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.2.3',
  'wtWebioAn8GraphTsSyncTime' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.2.4',
  'wtWebioAn8GraphDeviceClock' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.3',
  'wtWebioAn8GraphClockHrs' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.3.1',
  'wtWebioAn8GraphClockMin' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.3.2',
  'wtWebioAn8GraphClockDay' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.3.3',
  'wtWebioAn8GraphClockMonth' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.3.4',
  'wtWebioAn8GraphClockMonthDefinition' => 'WebGraph-8xThermometer-MIB::wtWebioAn8GraphClockMonth',
  'wtWebioAn8GraphClockYear' => '1.3.6.1.4.1.5040.1.2.6.3.1.2.3.5',
  'wtWebioAn8GraphBasic' => '1.3.6.1.4.1.5040.1.2.6.3.1.3',
  'wtWebioAn8GraphNetwork' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.1',
  'wtWebioAn8GraphIpAddress' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.1.1',
  'wtWebioAn8GraphSubnetMask' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.1.2',
  'wtWebioAn8GraphGateway' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.1.3',
  'wtWebioAn8GraphDnsServer1' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.1.4',
  'wtWebioAn8GraphDnsServer2' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.1.5',
  'wtWebioAn8GraphAddConfig' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.1.6',
  'wtWebioAn8GraphHTTP' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.2',
  'wtWebioAn8GraphStartup' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.2.1',
  'wtWebioAn8GraphGetHeaderEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.2.2',
  'wtWebioAn8GraphHttpPort' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.2.3',
  'wtWebioAn8GraphMail' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.3',
  'wtWebioAn8GraphMailAdName' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.3.1',
  'wtWebioAn8GraphMailReply' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.3.2',
  'wtWebioAn8GraphMailServer' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.3.3',
  'wtWebioAn1MailEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.3.4',
  'wtWebioAn8GraphMailAuthentication' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.3.5',
  'wtWebioAn8GraphMailAuthUser' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.3.6',
  'wtWebioAn8GraphMailAuthPassword' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.3.7',
  'wtWebioAn8GraphMailPop3Server' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.3.8',
  'wtWebioAn8GraphSNMP' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.4',
  'wtWebioAn8GraphSnmpCommunityStringRead' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.4.1',
  'wtWebioAn8GraphSnmpCommunityStringReadWrite' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.4.2',
  'wtWebioAn8GraphSystemTrapManagerIP' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.4.3',
  'wtWebioAn8GraphSystemTrapEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.4.4',
  'wtWebioAn8GraphSnmpEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.4.5',
  'wtWebioAn8GraphSnmpCommunityStringTrap' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.4.6',
  'wtWebioAn8GraphUDP' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.5',
  'wtWebioAn8GraphUdpPort' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.5.1',
  'wtWebioAn8GraphUdpEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.5.2',
  'wtWebioAn8GraphSyslog' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.6',
  'wtWebioAn8GraphSyslogServerIP' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.6.1',
  'wtWebioAn8GraphSyslogServerPort' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.6.2',
  'wtWebioAn8GraphSyslogSystemMessagesEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.6.3',
  'wtWebioAn8GraphSyslogEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.6.4',
  'wtWebioAn8GraphFTP' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.7',
  'wtWebioAn8GraphFTPServerIP' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.7.1',
  'wtWebioAn8GraphFTPServerControlPort' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.7.2',
  'wtWebioAn8GraphFTPUserName' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.7.3',
  'wtWebioAn8GraphFTPPassword' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.7.4',
  'wtWebioAn8GraphFTPAccount' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.7.5',
  'wtWebioAn8GraphFTPOption' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.7.6',
  'wtWebioAn8GraphFTPEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.3.7.7',
  'wtWebioAn8GraphDatalogger' => '1.3.6.1.4.1.5040.1.2.6.3.1.4',
  'wtWebioAn8GraphLoggerTimebase' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.1',
  'wtWebioAn8GraphLoggerTimebaseDefinition' => 'WebGraph-8xThermometer-MIB::wtWebioAn8GraphLoggerTimebase',
  'wtWebioAn8GraphLoggerSensorSel' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.2',
  'wtWebioAn8GraphDisplaySensorSel' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.3',
  'wtWebioAn8GraphSensorColorTable' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.4',
  'wtWebioAn8GraphSensorColorEntry' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.4.1',
  'wtWebioAn8GraphSensorColor' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.4.1.1',
  'wtWebioAn8GraphGraphicsSelectScale' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.4.1.2',
  'wtWebioAn8GraphAutoScaleEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.5',
  'wtWebioAn8GraphVerticalUpperLimit' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.6',
  'wtWebioAn8GraphVerticalLowerLimit' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.7',
  'wtWebioAn8GraphHorizontalZoom' => '1.3.6.1.4.1.5040.1.2.6.3.1.4.8',
  'wtWebioAn8GraphHorizontalZoomDefinition' => 'WebGraph-8xThermometer-MIB::wtWebioAn8GraphHorizontalZoom',
  'wtWebioAn8GraphAlarm' => '1.3.6.1.4.1.5040.1.2.6.3.1.5',
  'wtWebioAn8GraphAlarmCount' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.1',
  'wtWebioAn8GraphAlarmIfTable' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.2',
  'wtWebioAn8GraphAlarmIfEntry' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.2.1',
  'wtWebioAn8GraphAlarmNo' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.2.1.1',
  'wtWebioAn8GraphAlarmTable' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3',
  'wtWebioAn8GraphAlarmEntry' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1',
  'wtWebioAn8GraphAlarmTrigger' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.1',
  'wtWebioAn8GraphAlarmMin' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.2',
  'wtWebioAn8GraphAlarmMax' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.3',
  'wtWebioAn8GraphAlarmHysteresis' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.4',
  'wtWebioAn8GraphAlarmDelay' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.5',
  'wtWebioAn8GraphAlarmInterval' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.6',
  'wtWebioAn8GraphAlarmEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.7',
  'wtWebioAn8GraphAlarmEMailAddr' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.8',
  'wtWebioAn8GraphAlarmMailSubject' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.9',
  'wtWebioAn8GraphAlarmMailText' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.10',
  'wtWebioAn8GraphAlarmManagerIP' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.11',
  'wtWebioAn8GraphAlarmTrapText' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.12',
  'wtWebioAn8GraphAlarmMailOptions' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.13',
  'wtWebioAn8GraphAlarmTcpIpAddr' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.14',
  'wtWebioAn8GraphAlarmTcpPort' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.15',
  'wtWebioAn8GraphAlarmTcpText' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.16',
  'wtWebioAn8GraphAlarmClearMailSubject' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.17',
  'wtWebioAn8GraphAlarmClearMailText' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.18',
  'wtWebioAn8GraphAlarmClearTrapText' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.19',
  'wtWebioAn8GraphAlarmClearTcpText' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.20',
  'wtWebioAn8GraphAlarmSyslogIpAddr' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.21',
  'wtWebioAn8GraphAlarmSyslogPort' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.22',
  'wtWebioAn8GraphAlarmSyslogText' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.23',
  'wtWebioAn8GraphAlarmSyslogClearText' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.24',
  'wtWebioAn8GraphAlarmFtpDataPort' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.25',
  'wtWebioAn8GraphAlarmFtpFileName' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.26',
  'wtWebioAn8GraphAlarmFtpText' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.27',
  'wtWebioAn8GraphAlarmFtpClearText' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.28',
  'wtWebioAn8GraphAlarmFtpOptions' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.29',
  'wtWebioAn8GraphAlarmTimerCron' => '1.3.6.1.4.1.5040.1.2.6.3.1.5.3.1.30',
  'wtWebioAn8GraphGraphics' => '1.3.6.1.4.1.5040.1.2.6.3.1.6',
  'wtWebioAn8GraphGraphicsBase' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.1',
  'wtWebioAn8GraphGraphicsBaseEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.1.1',
  'wtWebioAn8GraphGraphicsBaseWidth' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.1.2',
  'wtWebioAn8GraphGraphicsBaseHeight' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.1.3',
  'wtWebioAn8GraphGraphicsBaseFrameColor' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.1.4',
  'wtWebioAn8GraphGraphicsBaseBackgroundColor' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.1.5',
  'wtWebioAn8GraphGraphicsBasePollingrate' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.1.6',
  'wtWebioAn8GraphGraphicsSelect' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.2',
  'wtWebioAn8GraphGraphicsSelectDisplaySensorSel' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.2.1',
  'wtWebioAn8GraphGraphicsSelectDisplayShowExtrem' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.2.2',
  'wtWebioAn8GraphSensorColorTable' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.2.3',
  'wtWebioAn8GraphGraphicsScale' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.3',
  'wtWebioAn8GraphGraphicsScaleAutoScaleEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.3.1',
  'wtWebioAn8GraphGraphicsScaleAutoFitEnable' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.3.2',
  'wtWebioAn8GraphGraphicsScale1Min' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.3.3',
  'wtWebioAn8GraphGraphicsScale2Min' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.3.4',
  'wtWebioAn8GraphGraphicsScale3Min' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.3.5',
  'wtWebioAn8GraphGraphicsScale4Min' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.3.6',
  'wtWebioAn8GraphGraphicsScale1Max' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.3.7',
  'wtWebioAn8GraphGraphicsScale2Max' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.3.8',
  'wtWebioAn8GraphGraphicsScale3Max' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.3.9',
  'wtWebioAn8GraphGraphicsScale4Max' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.3.10',
  'wtWebioAn8GraphGraphicsScale1Unit' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.3.11',
  'wtWebioAn8GraphGraphicsScale2Unit' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.3.12',
  'wtWebioAn8GraphGraphicsScale3Unit' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.3.13',
  'wtWebioAn8GraphGraphicsScale4Unit' => '1.3.6.1.4.1.5040.1.2.6.3.1.6.3.14',
  'wtWebioAn8GraphPorts' => '1.3.6.1.4.1.5040.1.2.6.3.2',
  'wtWebioAn8GraphPortTable' => '1.3.6.1.4.1.5040.1.2.6.3.2.1',
  'wtWebioAn8GraphPortEntry' => '1.3.6.1.4.1.5040.1.2.6.3.2.1.1',
  'wtWebioAn8GraphPortName' => '1.3.6.1.4.1.5040.1.2.6.3.2.1.1.1',
  'wtWebioAn8GraphPortText' => '1.3.6.1.4.1.5040.1.2.6.3.2.1.1.2',
  'wtWebioAn8GraphPortOffset1' => '1.3.6.1.4.1.5040.1.2.6.3.2.1.1.3',
  'wtWebioAn8GraphPortTemperature1' => '1.3.6.1.4.1.5040.1.2.6.3.2.1.1.4',
  'wtWebioAn8GraphPortOffset2' => '1.3.6.1.4.1.5040.1.2.6.3.2.1.1.5',
  'wtWebioAn8GraphPortTemperature2' => '1.3.6.1.4.1.5040.1.2.6.3.2.1.1.6',
  'wtWebioAn8GraphPortComment' => '1.3.6.1.4.1.5040.1.2.6.3.2.1.1.7',
  'wtWebioAn8GraphPortSensorSelect' => '1.3.6.1.4.1.5040.1.2.6.3.2.1.1.8',
  'wtWebioAn8GraphManufact' => '1.3.6.1.4.1.5040.1.2.6.3.3',
  'wtWebioAn8GraphMfName' => '1.3.6.1.4.1.5040.1.2.6.3.3.1',
  'wtWebioAn8GraphMfAddr' => '1.3.6.1.4.1.5040.1.2.6.3.3.2',
  'wtWebioAn8GraphMfHotline' => '1.3.6.1.4.1.5040.1.2.6.3.3.3',
  'wtWebioAn8GraphMfInternet' => '1.3.6.1.4.1.5040.1.2.6.3.3.4',
  'wtWebioAn8GraphMfDeviceTyp' => '1.3.6.1.4.1.5040.1.2.6.3.3.5',
  'wtWebioAn8GraphMfOrderNo' => '1.3.6.1.4.1.5040.1.2.6.3.3.6',
  'wtWebioAn8GraphDiag' => '1.3.6.1.4.1.5040.1.2.6.4',
  'wtWebioAn8GraphDiagErrorCount' => '1.3.6.1.4.1.5040.1.2.6.4.1',
  'wtWebioAn8GraphDiagBinaryError' => '1.3.6.1.4.1.5040.1.2.6.4.2',
  'wtWebioAn8GraphDiagErrorIndex' => '1.3.6.1.4.1.5040.1.2.6.4.3',
  'wtWebioAn8GraphDiagErrorMessage' => '1.3.6.1.4.1.5040.1.2.6.4.4',
  'wtWebioAn8GraphDiagErrorClear' => '1.3.6.1.4.1.5040.1.2.6.4.5',
};

$Monitoring::GLPlugin::SNMP::MibsAndOids::definitions->{'WebGraph-8xThermometer-MIB'} = {
  wtWebioAn8GraphStTzStartWday => {
    '1' => 'wtWebioAn8GraphStartWday-Sunday',
    '2' => 'wtWebioAn8GraphStartWday-Monday',
    '3' => 'wtWebioAn8GraphStartWday-Tuesday',
    '4' => 'wtWebioAn8GraphStartWday-Thursday',
    '5' => 'wtWebioAn8GraphStartWday-Wednesday',
    '6' => 'wtWebioAn8GraphStartWday-Friday',
    '7' => 'wtWebioAn8GraphStartWday-Saturday',
  },
  wtWebioAn8GraphHorizontalZoom => {
    '1' => 'wtWebioAn8GraphZoom-25min',
    '2' => 'wtWebioAn8GraphZoom-75min',
    '3' => 'wtWebioAn8GraphZoom-5hrs',
    '4' => 'wtWebioAn8GraphZoom-30hrs',
    '5' => 'wtWebioAn8GraphZoom-5days',
    '6' => 'wtWebioAn8GraphZoom-25days',
  },
  wtWebioAn8GraphSessCntrlConfigMode => {
    '0' => 'wtWebioAn8GraphSessCntrl-NoSession',
    '1' => 'wtWebioAn8GraphSessCntrl-Session',
  },
  wtWebioAn8GraphStTzStopMonth => {
    '1' => 'wtWebioAn8GraphStopMonth-January',
    '2' => 'wtWebioAn8GraphStopMonth-February',
    '3' => 'wtWebioAn8GraphStopMonth-March',
    '4' => 'wtWebioAn8GraphStopMonth-April',
    '5' => 'wtWebioAn8GraphStopMonth-May',
    '6' => 'wtWebioAn8GraphStopMonth-June',
    '7' => 'wtWebioAn8GraphStopMonth-July',
    '8' => 'wtWebioAn8GraphStopMonth-August',
    '9' => 'wtWebioAn8GraphStopMonth-September',
    '10' => 'wtWebioAn8GraphStopMonth-October',
    '11' => 'wtWebioAn8GraphStopMonth-November',
    '12' => 'wtWebioAn8GraphStopMonth-December',
  },
  wtWebioAn8GraphStTzStopWday => {
    '1' => 'wtWebioAn8GraphStopWday-Sunday',
    '2' => 'wtWebioAn8GraphStopWday-Monday',
    '3' => 'wtWebioAn8GraphStopWday-Tuesday',
    '4' => 'wtWebioAn8GraphStopWday-Thursday',
    '5' => 'wtWebioAn8GraphStopWday-Wednesday',
    '6' => 'wtWebioAn8GraphStopWday-Friday',
    '7' => 'wtWebioAn8GraphStopWday-Saturday',
  },
  wtWebioAn8GraphStTzStartMonth => {
    '1' => 'wtWebioAn8GraphStartMonth-January',
    '2' => 'wtWebioAn8GraphStartMonth-February',
    '3' => 'wtWebioAn8GraphStartMonth-March',
    '4' => 'wtWebioAn8GraphStartMonth-April',
    '5' => 'wtWebioAn8GraphStartMonth-May',
    '6' => 'wtWebioAn8GraphStartMonth-June',
    '7' => 'wtWebioAn8GraphStartMonth-July',
    '8' => 'wtWebioAn8GraphStartMonth-August',
    '9' => 'wtWebioAn8GraphStartMonth-September',
    '10' => 'wtWebioAn8GraphStartMonth-October',
    '11' => 'wtWebioAn8GraphStartMonth-November',
    '12' => 'wtWebioAn8GraphStartMonth-December',
  },
  wtWebioAn8GraphLoggerTimebase => {
    '1' => 'wtWebioAn8GraphDatalogger-1Min',
    '2' => 'wtWebioAn8GraphDatalogger-5Min',
    '3' => 'wtWebioAn8GraphDatalogger-15Min',
    '4' => 'wtWebioAn8GraphDatalogger-60Min',
  },
  wtWebioAn8GraphStTzStartMode => {
    '1' => 'wtWebioAn8GraphStartMode-first',
    '2' => 'wtWebioAn8GraphStartMode-second',
    '3' => 'wtWebioAn8GraphStartMode-third',
    '4' => 'wtWebioAn8GraphStartMode-fourth',
    '5' => 'wtWebioAn8GraphStartMode-last',
  },
  wtWebioAn8GraphStTzStopMode => {
    '1' => 'wtWebioAn8GraphStopMode-first',
    '2' => 'wtWebioAn8GraphStopMode-second',
    '3' => 'wtWebioAn8GraphStopMode-third',
    '4' => 'wtWebioAn8GraphStopMode-fourth',
    '5' => 'wtWebioAn8GraphStopMode-last',
  },
  wtWebioAn8GraphClockMonth => {
    '1' => 'wtWebioAn8GraphClockMonth-January',
    '2' => 'wtWebioAn8GraphClockMonth-February',
    '3' => 'wtWebioAn8GraphClockMonth-March',
    '4' => 'wtWebioAn8GraphClockMonth-April',
    '5' => 'wtWebioAn8GraphClockMonth-May',
    '6' => 'wtWebioAn8GraphClockMonth-June',
    '7' => 'wtWebioAn8GraphClockMonth-July',
    '8' => 'wtWebioAn8GraphClockMonth-August',
    '9' => 'wtWebioAn8GraphClockMonth-September',
    '10' => 'wtWebioAn8GraphClockMonth-October',
    '11' => 'wtWebioAn8GraphClockMonth-November',
    '12' => 'wtWebioAn8GraphClockMonth-December',
  },
};
